@@ -1,28 +1,36 @@
-from argparse import ArgumentParser
+#!/usr/bin/env python
+"""
+CLI interface to markdown-it-py
+
+Parse one or more markdown files, convert each to HTML, and print to stdout.
+"""
+from __future__ import annotations
+
+import argparse
+from collections.abc import Iterable, Sequence
 import sys
 
 from markdown_it import __version__
 from markdown_it.main import MarkdownIt
 
-
 version_str = "markdown-it-py [version {}]".format(__version__)
 
 
-def main(args=None):
+def main(args: Sequence[str] | None = None) -> int:
     namespace = parse_args(args)
     if namespace.filenames:
         convert(namespace.filenames)
     else:
         interactive()
-    return True
+    return 0
 
 
-def convert(filenames):
+def convert(filenames: Iterable[str]) -> None:
     for filename in filenames:
         convert_file(filename)
 
 
-def convert_file(filename):
+def convert_file(filename: str) -> None:
     """
     Parse a Markdown file and dump the output to stdout.
     """
@@ -31,16 +39,15 @@ def convert_file(filename):
             rendered = MarkdownIt().render(fin.read())
             print(rendered, end="")
     except OSError:
-        sys.exit('Cannot open file "{}".'.format(filename))
+        sys.stderr.write(f'Cannot open file "{filename}".\n')
+        sys.exit(1)
 
 
-def interactive(import_readline=False):
+def interactive() -> None:
     """
     Parse user input, dump to stdout, rinse and repeat.
     Python REPL style.
     """
-    if import_readline:
-        _import_readline()
     print_heading()
     contents = []
     more = False
@@ -57,9 +64,34 @@ def interactive(import_readline=False):
             break
 
 
-def parse_args(args):
+def parse_args(args: Sequence[str] | None) -> argparse.Namespace:
     """Parse input CLI arguments."""
-    parser = ArgumentParser()
+    parser = argparse.ArgumentParser(
+        description="Parse one or more markdown files, "
+        "convert each to HTML, and print to stdout",
+        # NOTE: Remember to update README.md w/ the output of `markdown-it -h`
+        epilog=(
+            f"""
+Interactive:
+
+  $ markdown-it
+  markdown-it-py [version {__version__}] (interactive)
+  Type Ctrl-D to complete input, or Ctrl-C to exit.
+  >>> # Example
+  ... > markdown *input*
+  ...
+  <h1>Example</h1>
+  <blockquote>
+  <p>markdown <em>input</em></p>
+  </blockquote>
+
+Batch:
+
+  $ markdown-it README.md README.footer.md > index.html
+"""
+        ),
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
     parser.add_argument("-v", "--version", action="version", version=version_str)
     parser.add_argument(
         "filenames", nargs="*", help="specify an optional list of files to convert"
@@ -67,17 +99,11 @@ def parse_args(args):
     return parser.parse_args(args)
 
 
-def _import_readline():
-    try:
-        import readline  # noqa: F401
-    except ImportError:
-        print("[warning] readline library not available.")
-
-
-def print_heading():
+def print_heading() -> None:
     print("{} (interactive)".format(version_str))
     print("Type Ctrl-D to complete input, or Ctrl-C to exit.")
 
 
 if __name__ == "__main__":
-    main(sys.argv[1:])
+    exit_code = main(sys.argv[1:])
+    sys.exit(exit_code)
