@@ -2,7 +2,7 @@ from ..token import Token
 from .state_core import StateCore
 
 
-def block(state: StateCore):
+def block(state: StateCore) -> None:
 
     if state.inlineMode:
         token = Token("inline", "", 0)
@@ -11,4 +11,6 @@ def block(state: StateCore):
         token.children = []
         state.tokens.append(token)
     else:
-        state.md.block.parse(state.src, state.md, state.env, state.tokens)
+        state.md.block.parse(
+            state.src, state.md, state.env, state.tokens, state.srcCharCode
+        )
