@@ -1,13 +1,13 @@
 # Process ![image](<src> "title")
+from __future__ import annotations
 
-from .state_inline import StateInline
 from ..common.utils import isSpace, normalizeReference
-from ..common.normalize_url import normalizeLink, validateLink
+from ..token import Token
+from .state_inline import StateInline
 
 
 def image(state: StateInline, silent: bool):
 
-    tokens = None
     label = None
     href = ""
     oldPos = state.pos
@@ -51,8 +51,8 @@ def image(state: StateInline, silent: bool):
         start = pos
         res = state.md.helpers.parseLinkDestination(state.src, pos, state.posMax)
         if res.ok:
-            href = normalizeLink(res.str)
-            if validateLink(href):
+            href = state.md.normalizeLink(res.str)
+            if state.md.validateLink(href):
                 pos = res.pos
             else:
                 href = ""
@@ -116,13 +116,13 @@ def image(state: StateInline, silent: bool):
 
         label = normalizeReference(label)
 
-        ref = state.env.references.get(label, None)
+        ref = state.env["references"].get(label, None)
         if not ref:
             state.pos = oldPos
             return False
 
-        href = ref.href
-        title = ref.title
+        href = ref["href"]
+        title = ref["title"]
 
     #
     # We found the end of the link, and know for a fact it's a valid link
@@ -131,15 +131,16 @@ def image(state: StateInline, silent: bool):
     if not silent:
         content = state.src[labelStart:labelEnd]
 
-        tokens = []
+        tokens: list[Token] = []
         state.md.inline.parse(content, state.md, state.env, tokens)
 
         token = state.push("image", "img", 0)
-        token.attrs = [["src", href], ["alt", ""]]
+        token.attrs = {"src": href, "alt": ""}
         token.children = tokens or None
+        token.content = content
 
         if title:
-            token.attrs.append(["title", title])
+            token.attrSet("title", title)
 
         # note, this is not part of markdown-it JS, but is useful for renderers
         if label and state.md.options.get("store_labels", False):
